@@ -69,10 +69,15 @@
                                   kVLCSettingNetworkSatIPChannelListUrl : @"",
                                   kVLCSettingEqualizerProfile : kVLCSettingEqualizerProfileDefaultValue,
                                   kVLCSettingEqualizerProfileDisabled : @(YES),
+                                  kVLCSettingPlaybackForwardBackwardEqual: @(YES),
+                                  kVLCSettingPlaybackTapSwipeEqual:  @(YES),
                                   kVLCSettingPlaybackForwardSkipLength : kVLCSettingPlaybackForwardSkipLengthDefaultValue,
                                   kVLCSettingPlaybackBackwardSkipLength : kVLCSettingPlaybackBackwardSkipLengthDefaultValue,
+                                  kVLCSettingPlaybackForwardSkipLengthSwipe : kVLCSettingPlaybackForwardSkipLengthSwipeDefaultValue,
+                                  kVLCSettingPlaybackBackwardSkipLengthSwipe : kVLCSettingPlaybackBackwardSkipLengthSwipeDefaultValue,
                                   kVLCSettingOpenAppForPlayback : kVLCSettingOpenAppForPlaybackDefaultValue,
                                   kVLCAutomaticallyPlayNextItem : @(YES),
+                                  kVLCPlaylistPlayNextItem: @(YES),
                                   kVLCSettingEnableMediaCellTextScrolling : @(NO),
                                   kVLCSettingShowThumbnails : kVLCSettingShowThumbnailsDefaultValue,
                                   kVLCSettingShowArtworks : kVLCSettingShowArtworksDefaultValue,
@@ -89,7 +94,8 @@
                                   kVLCPlayerShouldRememberState: @(YES),
                                   kVLCPlayerIsShuffleEnabled: kVLCPlayerIsShuffleEnabledDefaultValue,
                                   kVLCPlayerIsRepeatEnabled: kVLCPlayerIsRepeatEnabledDefaultValue,
-                                  kVLCSettingPlaybackSpeedDefaultValue: @(1.0)
+                                  kVLCSettingPlaybackSpeedDefaultValue: @(1.0),
+                                  kVLCPlayerShowPlaybackSpeedShortcut: @(NO)
     };
     [defaults registerDefaults:appDefaults];
 }
@@ -245,6 +251,16 @@
     [[VLCAppCoordinator sharedInstance] handleShortcutItem:shortcutItem];
 }
 
+- (id)application:(UIApplication *)application handlerForIntent:(INIntent *)intent
+{
+    if (@available(iOS 14.0, *)) {
+        if ([intent isKindOfClass:[INPlayMediaIntent class]] || [intent isKindOfClass:[INAddMediaIntent class]] || [intent isKindOfClass:[INSearchForMediaIntent class]]) {
+            return [[SirikitIntentCoordinator alloc] initWithMediaLibraryService: [[VLCAppCoordinator sharedInstance] mediaLibraryService]];;
+        }
+    }
+    return NULL;
+}
+
 #pragma mark - pass code validation
 - (VLCKeychainCoordinator *)keychainCoordinator
 {
