@@ -1,7 +1,7 @@
 /*****************************************************************************
  * VLC for iOS
  *****************************************************************************
- * Copyright (c) 2015 VideoLAN. All rights reserved.
+ * Copyright (c) 2015-2023 VideoLAN. All rights reserved.
  * $Id$
  *
  * Authors: Felix Paul Kühne <fkuehne # videolan.org>
@@ -44,6 +44,8 @@ typedef NS_ENUM(NSInteger, VLCPlayerScanState)
 @property (nonatomic) NSSet<UIGestureRecognizer *> *simultaneousGestureRecognizers;
 @property (nonatomic) BOOL disabledIdleTimer;
 
+@property (nonatomic) BOOL playbackUIShouldHide;
+
 @end
 
 @implementation VLCFullscreenMovieTVViewController
@@ -157,13 +159,27 @@ typedef NS_ENUM(NSInteger, VLCPlayerScanState)
     self.audioTitleLabel.hidden = YES;
     self.audioArtistLabel.hidden = YES;
     self.audioAlbumNameLabel.hidden = YES;
-    self.audioArtworkImageView.image = [UIImage imageNamed:@"about-app-icon"];
-    self.audioLargeBackgroundImageView.image = [UIImage imageNamed:@"about-app-icon"];
-    self.audioArtworkImageView.animateImageSetting = YES;
-    self.audioLargeBackgroundImageView.animateImageSetting = YES;
 
     VLCPlaybackService *vpc = [VLCPlaybackService sharedInstance];
     vpc.delegate = self;
+
+    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
+    if ([defaults boolForKey:kVLCPlayerShouldRememberState]) {
+        vpc.shuffleMode = [defaults boolForKey:kVLCPlayerIsShuffleEnabled];
+        vpc.repeatMode = [defaults integerForKey:kVLCPlayerIsRepeatEnabled];
+    }
+
+    self.playbackUIShouldHide = [defaults boolForKey:kVLCPlayerUIShouldHide];
+    if (self.playbackUIShouldHide) {
+        self.activityIndicator.alpha = 0.;
+        [self.activityIndicator stopAnimating];
+        self.bufferingLabel.hidden = YES;
+        self.audioArtworkImageView.image = nil;
+        self.audioLargeBackgroundImageView.image = nil;
+    } else {
+        [self updateThumbnailImageViewsWith:[UIImage imageNamed:@"about-app-icon"]];
+    }
+
     [vpc recoverPlaybackState];
 }
 
@@ -197,6 +213,8 @@ typedef NS_ENUM(NSInteger, VLCPlayerScanState)
 
     [self enableIdleTimer];
 
+    self.lastArtist = nil;
+
     [super viewWillDisappear:animated];
 }
 
@@ -739,6 +757,9 @@ static const NSInteger VLCJumpInterval = 10000; // 10 seconds
 }
 
 - (void)updateActivityIndicatorForState:(VLCMediaPlayerState)state {
+    if (self.playbackUIShouldHide) {
+        return;
+    }
     UIActivityIndicatorView *indicator = self.activityIndicator;
     switch (state) {
         case VLCMediaPlayerStateBuffering:
@@ -775,6 +796,16 @@ static const NSInteger VLCJumpInterval = 10000; // 10 seconds
     self.disabledIdleTimer = NO;
 }
 
+- (void)updateThumbnailImageViewsWith:(UIImage *)artworkImage
+{
+    if (artworkImage == nil && !self.playbackUIShouldHide) {
+        artworkImage = [UIImage imageNamed:@"about-app-icon"];
+    }
+
+    self.audioArtworkImageView.image = artworkImage;
+    self.audioLargeBackgroundImageView.image = artworkImage;
+}
+
 #pragma mark - PlaybackControls
 
 - (void)fireHidePlaybackControlsIfNotPlayingTimer:(NSTimer *)timer
@@ -890,7 +921,6 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
     NSString *albumName = metadata.albumName;
     self.titleLabel.text = title;
     if (metadata.isAudioOnly) {
-        self.audioArtworkImageView.image = nil;
         self.audioDescriptionTextView.hidden = YES;
         [self stopAudioDescriptionAnimation];
 
@@ -922,18 +952,17 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
                 self.audioAlbumNameLabel.hidden = YES;
             }];
         }
-        if (![self.lastArtist isEqualToString:artist]) {
-            UIImage *artworkImage = metadata.artworkImage;
 
-            if (artworkImage == nil) {
-                artworkImage = [UIImage imageNamed:@"about-app-icon"];
-            }
+        UIImage *artworkImage = metadata.artworkImage;
 
-            [UIView animateWithDuration:.3 animations:^{
-                self.audioArtworkImageView.image = artworkImage;
-                self.audioLargeBackgroundImageView.image = artworkImage;
-            }];
+        if ((![self.lastArtist isEqualToString:artist]) ||
+            (artworkImage != nil && self.audioArtworkImageView.image != artworkImage) ||
+            playbackService.mediaPlayerState == VLCMediaPlayerStateESAdded) {
+            dispatch_async(dispatch_get_main_queue(), ^{
+                [self updateThumbnailImageViewsWith:artworkImage];
+            });
         }
+
         self.lastArtist = artist;
         self.audioTitleLabel.text = title;
         self.audioTitleLabel.hidden = NO;
